#
# spec file for package gnome-kiosk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mutter_api 15

Name:           gnome-kiosk
Version:        47.0
Release:        1.3
Summary:        Mutter based compositor for kiosks
License:        GPL-2.0-or-later
URL:            https://gitlab.gnome.org/GNOME/gnome-kiosk
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gnome-desktop-4)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(ibus-1.0)
BuildRequires:  pkgconfig(libmutter-%{mutter_api})
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(mutter-clutter-%{mutter_api})
BuildRequires:  pkgconfig(mutter-cogl-%{mutter_api})
BuildRequires:  pkgconfig(mutter-cogl-pango-%{mutter_api})
BuildRequires:  pkgconfig(systemd)
Requires:       gnome-session

%description
Kiosk provides a desktop enviroment suitable for fixed purpose, or single
application deployments like wall displays and point-of-sale systems.

%package sample-app
Summary:        Search appliance sample app
Requires:       %{name} = %{version}
Requires:       MozillaFirefox
BuildArch:      noarch

%description sample-app
Search appliance sample app that demonstate how the kiosk
compositor is used.

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%fdupes -s %{buildroot}%{_datadir}

%files
%license COPYING
%{_bindir}/gnome-kiosk
%{_bindir}/gnome-kiosk-script
%dir %{_userunitdir}/gnome-session@gnome-kiosk-script.target.d
%{_userunitdir}/gnome-session@gnome-kiosk-script.target.d/session.conf
%{_userunitdir}/org.gnome.Kiosk.Script.service
%{_userunitdir}/org.gnome.Kiosk.target
%{_userunitdir}/org.gnome.Kiosk@wayland.service
%{_userunitdir}/org.gnome.Kiosk@x11.service
%{_datadir}/applications/org.gnome.Kiosk.Script.desktop
%{_datadir}/applications/org.gnome.Kiosk.desktop
%dir %{_datadir}/gnome-session
%dir %{_datadir}/gnome-session/sessions
%{_datadir}/gnome-session/sessions/gnome-kiosk-script.session
%dir %{_datadir}/wayland-sessions
%{_datadir}/wayland-sessions/gnome-kiosk-script-wayland.desktop
%{_datadir}/xsessions/gnome-kiosk-script-xorg.desktop
%dir %{_datadir}/dconf
%dir %{_datadir}/dconf/profile
%dir %{_datadir}/gnome-kiosk
%{_datadir}/dconf/profile/gnomekiosk
%{_datadir}/gnome-kiosk/gnomekiosk.dconf.compiled

%files sample-app
%{_datadir}/applications/org.gnome.Kiosk.SearchApp.desktop
%{_datadir}/gnome-session/sessions/org.gnome.Kiosk.SearchApp.session
%{_datadir}/wayland-sessions/org.gnome.Kiosk.SearchApp.Session.desktop
%{_datadir}/xsessions/org.gnome.Kiosk.SearchApp.Session.desktop

%changelog
* Wed Sep 18 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + No changes.
* Mon Sep 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.rc:
  + Fix crash on VT change.
  + Support gnome-shell introspection api when started with
  - -unsafe-mode.
  + CI updates.
* Wed Sep 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.alpha:
  + Port to mutter 47
  + Build with mutter that lacks X11 support
  + Typo fixes
- Drop gnome-kiosk-mutter-46.patch: No longer needed.
- Set mutter_api 15, following upstreams port to Mutter 47.
* Tue Mar 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Fixes with localed integration.
* Thu Mar  7 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add gnome-kiosk-mutter-46.patch: Fix build against mutter 46.rc.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Use gnome-text-editor instead of gedit for example script.
  + Keymap fix.
* Wed Jan 17 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + Add automount manager.
  + Support headless sessions.
  + Port to mutter 46.
  + Docs update.
- Set mutter_api 14, following upstreams port to Mutter 46.
* Sun Sep 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Complete port to mutter 45.
- Switch compression to zst in both service and tarball produced.
* Sun Sep 10 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 45.rc:
  + Switch to gnome-desktop4.
  + Port to mutter 45.
* Wed Aug  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0+4:
  + build: Switch to gnome-desktop-4
  + Build against mutter API version 13
- Replace pkgconfig(gnome-desktop-3.0) with
  pkgconfig(gnome-desktop-4) BuildRequires following upstream
  changes.
- Bump mutter_api define to 13 following upstream changes.
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + No changes, stable bump only.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Rename dconf profile to not have hyphen
  + Set dconf profile unconditionally
  + Use https instead of http in search-app
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Deprecation fixes
  + Require mutter 44
  + Compat fix for Anaconda Installer project
  + Script session double-starting fix
  + Allow changing background in gsettings
- Bump mutter_api define to 12 following upstream changes.
- Build sample-app as noarch.
* Tue Sep 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Meson build fixes.
  + Require mutter 43.
  + Clean up code format.
* Sat Sep 10 2022 bjorn.lie@gmail.com
- Update to version 42.0+12:
  * compositor:
  - Delete g_autoptr blank lines
  - Run entire codebase through uncrustify
  * scripts:
  - Don't force newline after variable declarations
  - Add uncrustify config
  * ci: Enforce coding style in CI
  * Bump mutter library requirements to 11 (mutter 43)
  * Drop unused positional argument to i18n.merge_file
- Switch to git checkout via source service, following this, bump
  mutter_api to 11 following upstream changes.
- Drop gnome-kiosk-fix-meson-061.patch: Fixed upstream.
* Tue Mar 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + No changes, stable bump only.
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-kiosk-fix-meson-061.patch: Fix build with meson 0.61
  and newer.
- Add fdupes BuildRequires and macro, remove duplicates.
- Split out gnome-kiosk-sample-app and add a hard Requires on
  MozillaFirefox, needed for the sample app.
* Mon Jan 24 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.alpha:
  + Port to mutter 42.
  + Docs fixes.
  + Build goo fixes.
- Drop gnome-kiosk-bump-mutter.patch: Fixed upstream.
- Drop mutter-devel, switch to proper pkgconfig() BuildRequires and
  add a mutter_api define and set it to 10. Add the following
  pkgconfig(libmutter-10), pkgconfig(mutter-clutter-10),
  pkgconfig(mutter-cogl-10) and pkgconfig(mutter-cogl-pango-10).
* Wed Jan 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-kiosk-bump-mutter.patch: Bump version of libmutter
  required.
* Thu Sep 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Initial package, version 41.0.
